@@ -19,8 +19,19 @@ index_collection::full_iterator::full_iterator(
     : i_(0),
       idx_(std::move(idx)),
       column_(column),
-      start_(0),
       end_(idx_->indexes_.size() - 1) {
+
+  auto n_inputs = idx_->indexes_.size();
+  auto n_rows_total = idx_->rows_;
+  auto n_rows_current_input = idx_->indexes_[i_]->num_rows();
+
+  if (n_rows_current_input == 0 && n_inputs > 1 && n_rows_total > 0) {
+    while(n_rows_current_input == 0) {
+      ++i_;
+      n_rows_current_input = idx_->indexes_[i_]->num_rows();
+    }
+  }
+
   auto col = idx_->indexes_[i_]->get_column(column_);
   it_ = col->begin();
   it_end_ = col->end();
@@ -36,15 +47,6 @@ void index_collection::full_iterator::next() {
   }
 }
 
-void index_collection::full_iterator::prev() {
-  --it_;
-  while (it_ == it_start_ && i_ > start_) {
-    --i_;
-    it_ = idx_->indexes_[i_]->get_column(column_)->end();
-    it_start_ = idx_->indexes_[i_]->get_column(column_)->begin();
-  }
-}
-
 void index_collection::full_iterator::advance(ptrdiff_t n) {
   if (n == 0) {
     return;
@@ -63,17 +65,7 @@ void index_collection::full_iterator::advance(ptrdiff_t n) {
     return;
   }
   if (n < 0) {
-    while (n < 0) {
-      auto diff = -(it_ - it_start_);
-      if (n > diff) {
-        it_ += n;
-        return;
-      }
-      it_ += (diff + 1);
-      n -= diff;
-      prev();
-    }
-    return;
+    throw std::runtime_error("negative advance not supported");
   }
 }
 
