@@ -9,7 +9,6 @@ namespace vroom {
 class base_iterator {
 public:
   virtual void next() = 0;
-  virtual void prev() = 0;
   virtual void advance(ptrdiff_t n) = 0;
   virtual bool equal_to(const base_iterator& it) const = 0;
   virtual ptrdiff_t distance_to(const base_iterator& it) const = 0;
@@ -57,17 +56,6 @@ public:
     return *this;
   }
 
-  iterator operator--(int) { /* postfix */
-    iterator copy(*this);
-    it_->prev();
-    return copy;
-  }
-
-  iterator& operator--() /* prefix */ {
-    it_->prev();
-    return *this;
-  }
-
   bool operator!=(const iterator& other) const {
     return !it_->equal_to(*other.it_);
   }
